@@ -2,6 +2,10 @@
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
+//! Bindings to *[libui-ng]*.
+//!
+//! [libui-ng]: https://github.com/libui-ng/libui-ng
+
 #![allow(
     non_camel_case_types,
     non_snake_case,
@@ -17,9 +21,11 @@ macro_rules! include_bindings {
 include_bindings!("bindings");
 include_bindings!("bindings-control-sigs");
 
+/// Platform-specific functionality.
 pub mod platform {
     macro_rules! def_platform {
-        ($mod:tt, $header:literal, $os:literal $(,)?) => {
+        ($mod:tt, $platform:literal, $header:literal, $os:literal $(,)?) => {
+            #[doc = concat!("Additional features available on ", $platform, " platforms.")]
             #[cfg(target_os = $os)]
             pub mod $mod {
                 use crate::*;
@@ -29,7 +35,7 @@ pub mod platform {
         };
     }
 
-    def_platform!(darwin, "bindings-darwin", "macos");
-    def_platform!(unix, "bindings-unix", "linux");
-    def_platform!(windows, "bindings-windows", "windows");
+    def_platform!(darwin, "Darwin", "bindings-darwin", "macos");
+    def_platform!(unix, "Unix", "bindings-unix", "linux");
+    def_platform!(windows, "Windows", "bindings-windows", "windows");
 }
